(function (document, $) {
    'use strict';
    // When dialog gets injected
    $(document).on('foundation-contentloaded', function () {
        $('.cq-dialog-showhide').each(function () {
            showhideHandler(this);
        });        
    });

    $(document).on("click", ".reset-fields", function (e) {
        e.preventDefault();

        var $dialog = $(this).closest(".cq-dialog");
        if (!$dialog.length) return;

        var confirmDialog = new Coral.Dialog();
        confirmDialog.set({
            variant: "warning",
            header: { innerHTML: "Confirm Reset" },
            content: { innerHTML: "Are you sure you want to reset all fields?" },
            footer: {
                innerHTML: `
                    <button is="coral-button" variant="primary" class="confirm-reset">Yes</button>
                    <button is="coral-button" variant="default" class="cancel-reset">No</button>
                `
            }
        });

        document.body.appendChild(confirmDialog);
        confirmDialog.addEventListener("click", function (event) {
            if (event.target.classList.contains("confirm-reset")) {
                resetFields($dialog);
                confirmDialog.hide();
                showNotification("Fields Reset", "All values have been cleared.");
            } else if (event.target.classList.contains("cancel-reset")) {
                confirmDialog.hide();
            }
        });
    
        confirmDialog.show();
    });

    function resetFields($dialog) {
        $dialog.find("input[type='text'], input[type='number'], textarea, select").each(function () {
            var defaultValue = this.defaultValue || "";
            $(this).val(defaultValue);
        });
    
        // Reset all input, select, textarea fields inside the dialog
        $dialog.find("input[type='text'], input[type='number'], textarea, select").val("");

        // Reset checkboxes and radio buttons
        $dialog.find("input[type='checkbox'], input[type='radio']").prop("checked", false);

        // Reset CoralUI fields
        $dialog.find("coral-select, coral-multifield, coral-checkbox, coral-radio").each(function () {
            this.value = "";
        });

        //reset pathfield
        $dialog.find("coral-pathbrowser").each(function () {
            $(this).find("input").val(""); // Clear the input field inside Coral PathBrowser
        });

        //reset color swatch in colorfield
        $dialog.find("coral-colorinput").each(function () {
            this.value = ""; // Reset color swatch value
        });
       
        //  // Find checkboxes with the show/hide target and reset them
        // $dialog.find("input[type='checkbox'][data-showhidetargetvalue='true']").each(function () {
        //     $(this).prop("checked", false).attr("data-showhidetargetvalue", "false").trigger("change");
        // });
        $dialog.find("[data-showhidetargetvalue='true']").each(function () {
            $(this).hide().attr("data-showhidetargetvalue", "false");
        });
    }
    
    function showNotification(title, message) {
        var toast = new Coral.Toast();
        toast.set({
            content: { innerHTML: `<strong>${title}</strong><br>${message}` }
        });
        document.body.appendChild(toast);
        toast.show();
    }
    
    // When input changes
    $(document).on('change', ':not(input[type=text]).cq-dialog-showhide', function () {
        showhideHandler(this);
    });
    // When textfield changes
    $(document).on('input', 'input[type=text].cq-dialog-showhide', function () {
        showhideHandler(this);
    });

    function showhideHandler(input) {
        // Targets that will be shown/hidden
        var target = $(input).data('cqDialogShowhideTarget');
        // If the input is inside a multifield, target only the elements inside the multifield item
        if ($(input).closest('coral-multifield-item').length) target = $(input).closest('coral-multifield-item').find(target);
        // Current selected value
        var value = $(input).val();
        if ($(input).is('coral-checkbox')) value = (!!input.checked).toString();

        $(target).each((_, elem) => {
            // If data-showhidetargetvalue is different from the selected value
            // Element should be hidden
            var isHidden = $(elem).attr('data-showhidetargetvalue') !== value;
            $(elem).toggleClass('hide', isHidden);

            /////clearall property values when Boxed is check and uncheck
            /////
            if (isHidden) {
                // clear color swatch in the colorfield when Boxed is check and uncheck
                $(elem).find('coral-colorinput').each(function () {
                    // Clear the text input inside Coral ColorInput
                    var colorInput = $(this);
                    var textField = colorInput.find('input[handle="input"]');
                    if (textField.length) {
                        textField.val(''); // Clear the text value
                        textField[0].removeAttribute('value'); // Remove the `value` attribute
                    }
            
                    // Reset the color preview button's background
                    var colorPreview = colorInput.find('[handle="colorPreview"]');
                    if (colorPreview.length) {
                        colorPreview.css('background-color', ''); // Clear the inline style
                    }
            
                    // Clear the selected value in the Coral UI color picker
                    this.value = ''; // Use the Coral component API to clear the value
                });
                
                // Clear all input fields within the hidden element
                $(elem).find('input, select, textarea').each(function () {
                    if ($(this).is(':checkbox, :radio')) {
                        $(this).prop('checked', false);
                    }else if ($(this).is('input[type="text"], input[type="number"], textarea')) {
                        // Clear text, number, and textarea fields
                        $(this).val('');
                    } else {
                        $(this).val('');
                    }
                }); 
            }
            // If target is a coral-tab
            if ($(elem).parent().parent().is('coral-panel')) {
                // Show/Hide tab label
                var tabIndex = $(elem).closest('coral-panel').index();
                $(elem)
                    .closest('coral-tabview')
                    .find('coral-tablist>coral-tab:nth-child(' + (tabIndex + 1) + ')')
                    .toggleClass('hide', isHidden);

                // Adjust Tab underline position (cloud only)
                // This behaviour can be seen when opening dialog in full-width
                var tab = $(elem).closest('coral-tabview').find('coral-tablist>coral-tab[aria-selected="true"]');
                if (tab.length) {
                    var line = $(elem).closest('coral-tabview').find('coral-tablist>div[handle="line"]');
                    var width = tab.width();
                    var position = tab.position().left + parseInt(tab.css('marginLeft').replace('px', ''));
                    line.css('transform', 'translate(' + Math.round(position) + 'px, 0px)');
                    line.css('width', Math.round(width) + 'px');
                }
            }
            // If element is hidden, remove all required inputs
            // To track which inputs were required, we store that info in the data-required/data-aria-required
            if (isHidden) {
                $(elem).find('[required]').attr('data-required', 'true').removeAttr('required')
                $(elem).find('[aria-required]').attr('data-aria-required', 'true').removeAttr('aria-required');
            }
            else {
                $(elem).find('[data-required]').attr('required', 'true').removeAttr('data-required');
                $(elem).find('[data-aria-required]').attr('aria-required', 'true').removeAttr('data-aria-required');
            }
        });
    }
})(document, Granite.$);