<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Interactive Info Images - AEM Component Documentation</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 40px;
            line-height: 1.6;
        }
        h1{
            color: blue;
        }
        ul {
            list-style-type: disc;
            margin-left: 20px;
        }
        .dialog-properties {
            border: 1px solid #ddd;
            padding: 15px;
            border-radius: 5px;
            background-color: #f9f9f9;
        }
        .dialog-properties ol {
            margin-left: 20px;
        }
    </style>
</head>
<body>
    <h1>Interactive Info Images - AEM Component Documentation</h1>    
    <h2>Overview</h2>
    <p>The Interactive Info Images component is a custom AEM component that allows users to display animated interactive image panels that reveal textual info content when hovered on.</p>    
    <h2>Features</h2>
    <ul>
        <li>Interactive image panels that reveal content on hover.</li>
        <li>Ability to add multiple items, each consisting of an image and its content.</li>
        <li>Only one content box is visible at a time when multiple items are present.</li>
        <li>Option to navigate content by hovering over different images.</li>
        <li>Supports title, text, and buttons for links within the content.</li>
        <li>Customizable animation effects.</li>
        <li>Responsive design ensuring proper display on all screen sizes.</li>
    </ul>    
    <h2>Functionality</h2>
    <ul>
        <li>Each item consists of an image and its content.</li>
        <li>By default, the content is hidden behind the image.</li>
        <li>When hovering over the image, the content appears and disappears when not hovering.</li>
        <li>Multiple items can be added; only one content box is visible at a time.</li>
        <li>Option to navigate through content by hovering over different images.</li>
        <li>The content includes:
            <ul>
                <li>Title</li>
                <li>Text</li>
                <li>Buttons (for links with styling options)</li>
            </ul>
        </li>
    </ul>    
    <h2>Dialog Properties</h2>
    <h3>1. General Configuration</h3>
    <ul>
        <li><strong>activeItemPosition</strong> – Option to input the number corresponding to the position of the item you wish to be opened initially.</li>
        <li><strong>Child Elements</strong> – Option to add multiple items.
            <ul>
                <li><strong>Image</strong> – Option to add Right Side Image.</li>
                <li><strong>Title</strong> – Option to add Title for the content on the left side.</li>
                <li><strong>Text</strong> – Option to add Description for the content on the left side.</li>
                <li><strong>Button Text</strong> – Label for button.</li>
                <li><strong>Url</strong> – Link for button.</li>
                <li><strong>Open In New Window</strong> – Decide whether the link opens in a new window or not.</li>
                <li><strong>Add nofollow</strong> – Decide whether the button link should have a nofollow attribute.</li>
            </ul>
        </li>
    </ul>    
    <h3>2. Button Configuration</h3>
    <ul>
        <li><strong>Layout</strong> – Option to set layout for button:
            <ul>
                <li>Filled – Button displays with background and outline.</li>
                <li>Outlined – Button has an outline but no background color.</li>
                <li>Textual – Button displays without background and outline.</li>
            </ul>
        </li>
        <li><strong>Type</strong> – Adds extra features to the button:
            <ul>
                <li>Standard – No extra styles apply to button.</li>
                <li>With Inner Border – Adds an inner border to button.</li>
                <li>Icon Boxed – Sets an icon inside a box (icon appears alongside the button).</li>
            </ul>
        </li>
        <li><strong>Size</strong> – Option to set button size:
            <ul>
                <li>Normal – Default button size.</li>
                <li>Small – Smaller than normal.</li>
                <li>Large – Larger than normal.</li>
                <li>Normal Full Width – Normal size but spans the full width.</li>
            </ul>            
        </li>
        <li><strong>Enable Button Text Underline</strong> – Option to enable underline for button.</li>
    </ul>  
    <p><em>(Note: Type and size are not visible if Layout = Textual.)</em></p>  
    <h3>3. Button Icon Configuration</h3>
    <ul>
        <li><strong>Icon</strong> – Option to add an icon alongside the button.</li>
        <li><strong>Icon Position</strong> – Option to set the position of the icon relative to the button:
            <ul>
                <li>Right – Icon appears to the right of the button.</li>
                <li>Left – Icon appears to the left of the button.</li>
            </ul>
        </li>
    </ul>    
    <h2>Usage Instructions</h2>
    <ol>
        <li>Add the component to an AEM page.</li>
        <li>Configure images and content for each item.</li>
        <li>Customize styling and effects based on preferences.</li>
        <li>Preview and publish to see the interactive images in action.</li>
    </ol>    
    <h2>Additional Notes</h2>
    <ul>
        <li>Ensure images are optimized for better performance.</li>
        <li>Use contrasting styles to enhance visibility and user experience.</li>
    </ul>    
    <h2>Conclusion</h2>
    <p>This component enhances user engagement by adding interactive elements to images, making content visually appealing and informative. It provides flexibility and ease of customization within AEM’s authoring environment.</p>
</body>
</html>

